@@ -1218,7 +1218,11 @@ bool BayonneSession::stateXfer(Event *event)
 	switch(event->id)
 	{
 	case ENTER_STATE:
-		error("transfer-failed");
+		event->errmsg = "feature-unsupported";
+	case ERROR_STATE:
+		error(event->errmsg);
+		if(setLibexec(RESULT_FAILED))
+			return true;
 		setRunning();
 		return true;
 	case TIMER_EXPIRED:
@@ -1622,6 +1626,8 @@ bool BayonneSession::stateRunning(Event *event)
 		check();
 		if(state.handler == &BayonneSession::stateRunning)
 			startTimer(step_timer);
+		else
+			setSymbol("script.error", "none");
 		return true;
 	}
 
