@@ -25,6 +25,7 @@ using namespace ost;
 using namespace std;
 
 static Keydata::Define driver[] = {
+	{"type", "proto"},
 	{"stack", "0"},
 	{"events", "128"},
 	{"priority", "0"},
@@ -387,7 +388,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(!cp)
 		cp = getLast("duration");
 
-	reg->duration = 60000 * atol(cp);
+	reg->duration = 1000 * atol(cp);
 	reg->line = line;
 	reg->scr = scr;
 
@@ -536,9 +537,9 @@ void Driver::run(void)
 	char cbuf[256];
 	Registry *reg;
 	ScriptImage *img;
-	const char *caller;
-	const char *dialed;
-	const char *display;
+	const char *caller = NULL;
+	const char *dialed = NULL;
+	const char *display = NULL;
 	BayonneSession *s;
 	Session *session;
 	char *k, *v, *l, *p, *line;
@@ -670,13 +671,15 @@ sip404:
                         else
                                 dialed = uri->username;
 
-			if(osip_from_parse(from, sevent->remote_uri) == 0)
-				caller = "unknown";
+			if(osip_from_parse(from, sevent->remote_uri) != 0)
+				caller = NULL;
 			else if(from->url->username == NULL)
-				caller = "unknown";
+				caller = NULL;
 			else
 				caller = from->url->username;
 
+			if(!caller)
+
 			if(!dialed || !*dialed)
 				dialed = "unknown";
 
@@ -721,7 +724,9 @@ sip404:
                         session->setConst("session.uri_local", caller);
 
 			setString(buf, sizeof(buf), sevent->remote_uri);
-			caller = buf;
+			caller = strchr(buf, '<');
+			if(!caller)
+				caller = buf;			
 			if(*caller == '<')
 			{
 				p = strchr(++caller, '>');
@@ -739,6 +744,9 @@ sip404:
                                         *p = 0;
                         }
                         session->setConst("session.uri_contact", caller);
+			p = strchr(caller, '@');
+			if(p)
+				session->setConst("session.server", ++p);
 
 			if(sevent->refer_to[0])
 				session->setConst("session.refer", sevent->refer_to);
